#ifndef OBGTK_WINDOW_H
#define OBGTK_WINDOW_H 1

#include <obgtk/obgtkBin.h>
#include <obgtk/obgtkWidget.h>
#ifdef GTK_HAVE_FEATURES_1_1_0
#include <obgtk/obgtkAccelGroup.h>
#else
#include <obgtk/obgtkAcceleratorTable.h>
#endif
#include <gtk/gtkwindow.h>

@interface Gtk_Window : Gtk_Bin
{
@public
  GtkWindow *gtkwindow;
}
- castGtkWindow:(GtkWindow *) castitem;
- init;
- initWithWindowType:(GtkWindowType) wintype;
- set_title:(gchar *) title;
- set_focus:(Gtk_Widget *) focus;
- set_default:(Gtk_Widget *) defaultw;
- set_policy:(gint) allow_shrink
   allowGrow:(gint) allow_grow
  autoShrink:(gint) auto_shrink;
#ifdef GTK_HAVE_FEATURES_1_1_0
- add_accel_group:(Gtk_AccelGroup *) group;
- remove_accel_group:(Gtk_AccelGroup *) group;
#else
- add_accelerator_table:(Gtk_AcceleratorTable *) table;
- remove_accelerator_table:(Gtk_AcceleratorTable *) table;
#endif
- set_position:(GtkWindowPosition) position;

@end

#endif /* OBGTK_WINDOW_H */
